from setuptools import setup

setup(name='distributions_z1',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions_z1'],
      author = 'Richmond Yeboah',
      author_email = 'Richmond.k.yeboah@gmail.com',
      zip_safe=False)
